Must create a `feeds.yaml` file in this format:

```yaml
sources:
    source-id-1:
        name: "Source Name"
        feeds:
            - id: source-1-id
              url: feed-1-url
            - id: source-2-id
              url: feed-2-url
            - id: source-3-id
              url: feed-3-url
    
    source-id-2:
        name: "Source Name"
        feeds:
            - id: source-1-id
              url: feed-1-url
            - id: source-2-id
              url: feed-2-url
            - id: source-3-id
              url: feed-3-url
```
